@@ -198,9 +198,10 @@ def load_cache_driver(userId, chrome_options = None, **kwargs):
     return load_driver(chrome_options=chrome_options, mode=['cache'], userId=userId, **kwargs)
 
 
-def n_login(driver: WebDriver, nid: str, pwd: str, keep_login: bool=True, ip_safe: bool=False, force: bool=False):
+def n_login(driver: WebDriver, nid: str, pwd: str, keep_login: bool=True, ip_safe: bool=False, force: bool=False, mobile: bool=False):
     """
-    It logs in to Naver.com using the given ID and password
+    It logs in to Naver.com and returns True if it was successful, False if it was not, and a string if
+    there was a problem
     
     :param driver: WebDriver
     :type driver: WebDriver
@@ -208,73 +209,140 @@ def n_login(driver: WebDriver, nid: str, pwd: str, keep_login: bool=True, ip_saf
     :type nid: str
     :param pwd: str
     :type pwd: str
-    :param keep_login: If True, the login will be kept. If False, the login will be temporary, defaults
-    to False
+    :param keep_login: If True, the account will be kept logged in. If False, the account will be logged
+    out after closing the browser, defaults to True
     :type keep_login: bool (optional)
-    :param ip_safe: If you want to use the IP safe feature, set it to True, defaults to False
+    :param ip_safe: If True, it will use the IP Safe feature, defaults to False
     :type ip_safe: bool (optional)
-    :param force: bool=False, defaults to False
+    :param force: If True, it will force the login process, defaults to False
     :type force: bool (optional)
-    :return: A boolean value.
+    :param mobile: bool=False, defaults to False
+    :type mobile: bool (optional)
+    :return: a boolean value.
     """
+    
+    if mobile:
+        
+        if force:
+            pass
+        else:
+            
+            try:
+                driver.get('https://m.naver.com/aside/')
+            except TimeoutException:
+                try:
+                    driver.refresh()
+                except TimeoutException:
+                    sys.stdout.write('네트워크 문제로 로그인 되어있는지 확인이 불가합니다.\n')
+                    return False
+            except Exception as e:
+                sys.stdout.write(f'{e}\n')
+                return False
+            
+            time.sleep(.5)
+            
+            try:
+                if driver.find_element(By.CSS_SELECTOR, '.MM_LOGINOUT').text == '로그아웃':
+                    return True
+            except:
+                pass
+        
+        driver.header_overrides = {'Referer': 'http://m.naver.com/aside/'}
+        driver.get('https://nid.naver.com/nidlogin.login?svctype=262144&amp;url=http://m.naver.com/aside/')
 
-    if force:
-        driver.delete_all_cookies()
-        driver.header_overrides = {'Referer': f'https://www.naver.com/'}
-        driver.get('https://nid.naver.com/nidlogin.login?mode=form&url=https%3A%2F%2Fwww.naver.com')
-    else:
-        driver.get('https://www.naver.com')
+        origin_clip = pyperclip.paste()
         try:
-            driver.find_element(By.CSS_SELECTOR, 'a.btn_logout')
-        except:
+            pyperclip.copy(nid)
+            driver.find_elements(By.CSS_SELECTOR, '#id')[0].send_keys(Keys.CONTROL, 'v')
+            time.sleep(0.5)
+
+            pyperclip.copy(pwd)
+            driver.find_elements(By.CSS_SELECTOR, '#pw')[0].send_keys(Keys.CONTROL, 'v')
+        finally:
+            pyperclip.copy(origin_clip)
+
+        if keep_login:
+            if driver.find_element(By.CSS_SELECTOR, 'input#stay').get_attribute('value').lower() == 'off':
+                driver.execute_script('arguments[0].click();', driver.find_element(By.CSS_SELECTOR, 'input#stay'))
+        else:
+            if driver.find_element(By.CSS_SELECTOR, 'input#stay').get_attribute('value').lower() == 'on':
+                driver.execute_script('arguments[0].click();', driver.find_element(By.CSS_SELECTOR, 'input#stay'))
+
+        driver.find_elements(By.CSS_SELECTOR, 'button[class="btn_check"]')[0].click()
+        time.sleep(1)
+    
+    else:
+        
+        if force:
             pass
         else:
             try:
-                sys.stdout.write(f'''{driver.find_element(By.CSS_SELECTOR, 'div.email.MY_EMAIL').text.split('@')[0]} : 이미 로그인 되어있습니다.\n''')
+                driver.get('https://www.naver.com')
+            except TimeoutException:
+                try:
+                    driver.refresh()
+                except TimeoutException:
+                    sys.stdout.write('네트워크 문제로 로그인 되어있는지 확인이 불가합니다.\n')
+                    return False
+            except Exception as e:
+                sys.stdout.write(f'{e}\n')
+                return False
+            time.sleep(.5)
+            try:
+                logout_iframe = driver.find_element(By.CSS_SELECTOR, 'iframe#minime')
+                driver.switch_to.frame(logout_iframe)
+                driver.find_element(By.CSS_SELECTOR, 'a.btn_logout')
             except:
                 pass
+            else:
+                try:
+                    sys.stdout.write(f'''{driver.find_element(By.CSS_SELECTOR, 'div.email.MY_EMAIL').text.split('@')[0]} : 이미 로그인 되어있습니다.\n''')
+                except:
+                    pass
+                finally:
+                    return True
             finally:
-                return True
+                driver.switch_to.default_content()
 
-    # driver.header_overrides = {'Referer': f'https://www.naver.com/', 'User-Agent': 'Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/104.0.0.0 Safari/537.36'}
-    driver.header_overrides = {'Referer': f'https://www.naver.com/'}
-    driver.get('https://nid.naver.com/nidlogin.login?mode=form&url=https%3A%2F%2Fwww.naver.com')
-    
-    time.sleep(.5)
-
-    origin_clip = pyperclip.paste()
-    try:
-        pyperclip.copy(nid)
-        driver.find_element(By.CSS_SELECTOR, 'input#id').send_keys(Keys.CONTROL, 'v')
+        # driver.header_overrides = {'Referer': 'https://www.naver.com/', 'User-Agent': 'Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/104.0.0.0 Safari/537.36'}
+        driver.header_overrides = {'Referer': 'https://www.naver.com/'}
+        driver.get('https://nid.naver.com/nidlogin.login?mode=form&url=https%3A%2F%2Fwww.naver.com')
+        
         time.sleep(.5)
-        pyperclip.copy(pwd)
-        driver.find_element(By.CSS_SELECTOR, 'input#pw').send_keys(Keys.CONTROL, 'v')
-    finally:
-        pyperclip.copy(origin_clip)
-    
-    if keep_login:
-        if driver.find_element(By.CSS_SELECTOR, 'input#keep').get_attribute('value').lower() == 'off':
-            driver.execute_script('arguments[0].click();', driver.find_element(By.CSS_SELECTOR, 'input#keep'))
-    else:
-        if driver.find_element(By.CSS_SELECTOR, 'input#keep').get_attribute('value').lower() == 'on':
-            driver.execute_script('arguments[0].click();', driver.find_element(By.CSS_SELECTOR, 'input#keep'))
 
-    time.sleep(1)
+        origin_clip = pyperclip.paste()
+        try:
+            pyperclip.copy(nid)
+            driver.find_element(By.CSS_SELECTOR, 'input#id').send_keys(Keys.CONTROL, 'v')
+            time.sleep(.5)
+            pyperclip.copy(pwd)
+            driver.find_element(By.CSS_SELECTOR, 'input#pw').send_keys(Keys.CONTROL, 'v')
+        finally:
+            pyperclip.copy(origin_clip)
+        
+        if keep_login:
+            if driver.find_element(By.CSS_SELECTOR, 'input#keep').get_attribute('value').lower() == 'off':
+                driver.execute_script('arguments[0].click();', driver.find_element(By.CSS_SELECTOR, 'input#keep'))
+        else:
+            if driver.find_element(By.CSS_SELECTOR, 'input#keep').get_attribute('value').lower() == 'on':
+                driver.execute_script('arguments[0].click();', driver.find_element(By.CSS_SELECTOR, 'input#keep'))
 
-    if ip_safe:
-        if driver.find_element(By.CSS_SELECTOR, 'input#smart_LEVEL').get_attribute('value') == '-1':
-            driver.execute_script('arguments[0].click();', driver.find_element(By.CSS_SELECTOR, 'input#switch'))
-    else:
-        if driver.find_element(By.CSS_SELECTOR, 'input#smart_LEVEL').get_attribute('value') == '1':
-            driver.execute_script('arguments[0].click();', driver.find_element(By.CSS_SELECTOR, 'input#switch'))
-    
-    time.sleep(1)
+        time.sleep(1)
 
-    # 로그인 버튼 클릭
-    try:
-        driver.find_element(By.CSS_SELECTOR, 'button[type="submit"][id="log.login"]').click()
-    except:
-        driver.execute_script('arguments[0].click();', driver.find_element(By.CSS_SELECTOR, 'button[type="submit"][id="log.login"]'))
+        if ip_safe:
+            if driver.find_element(By.CSS_SELECTOR, 'input#smart_LEVEL').get_attribute('value') == '-1':
+                driver.execute_script('arguments[0].click();', driver.find_element(By.CSS_SELECTOR, 'input#switch'))
+        else:
+            if driver.find_element(By.CSS_SELECTOR, 'input#smart_LEVEL').get_attribute('value') == '1':
+                driver.execute_script('arguments[0].click();', driver.find_element(By.CSS_SELECTOR, 'input#switch'))
+        
+        time.sleep(1)
+
+        # 로그인 버튼 클릭
+        try:
+            driver.find_element(By.CSS_SELECTOR, 'button[type="submit"][id="log.login"]').click()
+        except:
+            driver.execute_script('arguments[0].click();', driver.find_element(By.CSS_SELECTOR, 'button[type="submit"][id="log.login"]'))
 
     try:
         WebDriverWait(driver, 2.5).until(expected_conditions.staleness_of(driver.find_element(By.TAG_NAME, 'html')))
@@ -296,6 +364,9 @@ def n_login(driver: WebDriver, nid: str, pwd: str, keep_login: bool=True, ip_saf
     elif 'https://www.naver.com/' == now_url:
         flag = True
     
+    elif 'https://m.naver.com/' == now_url:
+        flag = True
+    
     elif 'idRelease' in now_url and '대량생성' in source:
         flag = '로그인제한(대량생성ID)'
 
